/*
 * Copyright (C) 2005-2009 Makoto Sato. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.objectfanatics.assertion.constraints;

import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.PARAMETER;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Documented;
import java.lang.annotation.Retention;
import java.lang.annotation.Target;

/**
 * The annotated element must not be <code>null</code> or greater than the specified value.
 * <p/>
 * Supported types are:
 * <ul>
 * <li><code>byte</code></li>
 * <li><code>short</code></li>
 * <li><code>int</code></li>
 * <li><code>long</code></li>
 * <li><code>float</code></li>
 * <li><code>double</code></li>
 * <li><code>Byte</code></li>
 * <li><code>Short</code></li>
 * <li><code>Integer</code></li>
 * <li><code>Long</code></li>
 * <li><code>Float</code></li>
 * <li><code>Double</code></li>
 * <li><code>BigInteger</code></li>
 * <li><code>BigDecimal</code></li>
 * <li><code>AtomicInteger</code></li>
 * <li><code>AtomicLong</code></li>
 * </ul>
 * <p/>
 * 
 * @author Makoto Sato
 */
@Documented
@Retention(RUNTIME)
@Target( { METHOD, PARAMETER })
@ConstraintAnnotation
public @interface Max {
	double value();
}
